Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/qa
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2023-05-25 00:07:24 +0300
committerGitLab Bot <gitlab-bot@gitlab.com>2023-05-25 00:07:24 +0300
commit4e341944acb64c4aaa8ecd467958d28c5bcfcc3a (patch)
treebf17bb5ac413216c5edd6602fcab986e3266bbca /qa
parentca386bfc0cf083e0ccb477995378061fc2a15b66 (diff)
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'qa')
-rw-r--r--qa/qa/specs/features/browser_ui/4_verify/pipeline/include_multiple_files_from_multiple_projects_spec.rb56
-rw-r--r--qa/qa/specs/features/browser_ui/4_verify/pipeline/pipeline_editor_tabs_spec.rb12
2 files changed, 17 insertions, 51 deletions
diff --git a/qa/qa/specs/features/browser_ui/4_verify/pipeline/include_multiple_files_from_multiple_projects_spec.rb b/qa/qa/specs/features/browser_ui/4_verify/pipeline/include_multiple_files_from_multiple_projects_spec.rb
index dc8db7ec387..59591fbe1cd 100644
--- a/qa/qa/specs/features/browser_ui/4_verify/pipeline/include_multiple_files_from_multiple_projects_spec.rb
+++ b/qa/qa/specs/features/browser_ui/4_verify/pipeline/include_multiple_files_from_multiple_projects_spec.rb
@@ -1,10 +1,7 @@
# frozen_string_literal: true
module QA
- RSpec.describe 'Verify', :runner, product_group: :pipeline_authoring, feature_flag: {
- name: 'ci_batch_project_includes_context',
- scope: :global
- } do
+ RSpec.describe 'Verify', :runner, product_group: :pipeline_authoring do
describe 'Include multiple files from multiple projects' do
let(:executor) { "qa-runner-#{Faker::Alphanumeric.alphanumeric(number: 8)}" }
@@ -34,7 +31,7 @@ module QA
end
end
- def before_do
+ before do
Flow::Login.sign_in
add_included_files_for(main_project)
@@ -50,44 +47,17 @@ module QA
runner.remove_via_api!
end
- context 'when FF is on', testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/396374' do
- before do
- Runtime::Feature.enable(:ci_batch_project_includes_context, project: main_project)
- sleep 60
-
- before_do
- end
-
- it 'runs the pipeline with composed config' do
- Page::Project::Pipeline::Show.perform do |pipeline|
- aggregate_failures 'pipeline has all expected jobs' do
- expect(pipeline).to have_job('test_for_main')
- expect(pipeline).to have_job("test1_for_#{project1.full_path}")
- expect(pipeline).to have_job("test1_for_#{project2.full_path}")
- expect(pipeline).to have_job("test2_for_#{project1.full_path}")
- expect(pipeline).to have_job("test2_for_#{main_project.full_path}")
- end
- end
- end
- end
-
- context 'when FF is off', testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/396375' do
- before do
- Runtime::Feature.disable(:ci_batch_project_includes_context, project: main_project)
- sleep 60
-
- before_do
- end
-
- it 'runs the pipeline with composed config' do
- Page::Project::Pipeline::Show.perform do |pipeline|
- aggregate_failures 'pipeline has all expected jobs' do
- expect(pipeline).to have_job('test_for_main')
- expect(pipeline).to have_job("test1_for_#{project1.full_path}")
- expect(pipeline).to have_job("test1_for_#{project2.full_path}")
- expect(pipeline).to have_job("test2_for_#{project1.full_path}")
- expect(pipeline).to have_job("test2_for_#{main_project.full_path}")
- end
+ it(
+ 'runs the pipeline with composed config',
+ testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/396374'
+ ) do
+ Page::Project::Pipeline::Show.perform do |pipeline|
+ aggregate_failures 'pipeline has all expected jobs' do
+ expect(pipeline).to have_job('test_for_main')
+ expect(pipeline).to have_job("test1_for_#{project1.full_path}")
+ expect(pipeline).to have_job("test1_for_#{project2.full_path}")
+ expect(pipeline).to have_job("test2_for_#{project1.full_path}")
+ expect(pipeline).to have_job("test2_for_#{main_project.full_path}")
end
end
end
diff --git a/qa/qa/specs/features/browser_ui/4_verify/pipeline/pipeline_editor_tabs_spec.rb b/qa/qa/specs/features/browser_ui/4_verify/pipeline/pipeline_editor_tabs_spec.rb
index 1a8f07ba621..a9f46e394f7 100644
--- a/qa/qa/specs/features/browser_ui/4_verify/pipeline/pipeline_editor_tabs_spec.rb
+++ b/qa/qa/specs/features/browser_ui/4_verify/pipeline/pipeline_editor_tabs_spec.rb
@@ -84,11 +84,7 @@ module QA
context 'when CI has invalid syntax' do
it(
'shows invalid validations',
- testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/368333',
- quarantine: {
- issue: 'https://gitlab.com/gitlab-org/gitlab/-/issues/412769',
- type: :broken
- }
+ testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/368333'
) do
invalid_msg = 'syntax is invalid'
@@ -107,10 +103,10 @@ module QA
show.go_to_full_configuration_tab
# TODO: remove this retry when
# https://gitlab.com/gitlab-org/gitlab/-/issues/378536 is resolved
- show.retry_until(max_attempts: 2, reload: true, sleep_interval: 1) { show.has_no_alert? }
- expect(show).to have_source_editor
+ expect { show.has_source_editor? }
+ .to eventually_be_truthy.within(max_attempts: 2, reload_page: show, sleep_interval: 1)
expect(show.ci_syntax_validate_message).to have_content('CI configuration is invalid')
end
@@ -107,10 +103,10 @@ module QA
show.go_to_full_configuration_tab
- # TODO: remove this retry when
+ # TODO: remove page reload when
# https://gitlab.com/gitlab-org/gitlab/-/issues/378536 is resolved